API documentation
-----------------

The following documentation is based on the source code of version |release| of
the `qpass` package.

.. contents::
   :local:

:mod:`qpass`
~~~~~~~~~~~~

.. automodule:: qpass
   :members:

:mod:`qpass.cli`
~~~~~~~~~~~~~~~~

.. automodule:: qpass.cli
   :members:

:mod:`qpass.exceptions`
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: qpass.exceptions
   :members:
